#!/bin/bash

# $1 major
# $2 minor
# $3 patch
# $4 prerelease
# $5 output-file

readonly VER_MAJOR=$1
readonly VER_MINOR=$2
readonly VER_PATCH=$3
readonly VER_PRERELEASE=$4
readonly OUT_FILE=$5

VER_STRING=${VER_MAJOR}.${VER_MINOR}.${VER_PATCH}
if [ "x${VER_PRERELEASE}" != "x" ]; then
    VER_STRING=${VER_STRING}-${VER_PRERELEASE}
fi

METADATA=$(git describe --always --dirty --broken --exclude=*)
VER_STRING=${VER_STRING}+${METADATA}

if [ \( ! -e ${OUT_FILE} \) ] || [ "${VER_STRING}" != "$(grep VER_STR ${OUT_FILE} | sed 's/^#define VER_STR[[:space:]]*"\(.*\)"$/\1/')" ]; then
    echo "generating ${OUT_FILE}";
    HEADER_GUARD=$(echo -n ${OUT_FILE}__ | tr '[:lower:][:punct:]' '[:upper:]_');
    cat << EOF > ${OUT_FILE}
#ifndef ${HEADER_GUARD}
#define ${HEADER_GUARD}

/*
 * This file is autogenerated - DO NOT MODIFY
 *
 * This file should be included by a fixed, well-known set of .c sources
 * to let developers to express right dependencies in the makefile.
 * This is to cancel the risk of incorrect or failed builds
 */

#define VER_MAJOR        ${VER_MAJOR}
#define VER_MINOR        ${VER_MINOR}
#define VER_PATCH        ${VER_PATCH}
#define VER_PRERELEASE   "${VER_PRERELEASE}"
#define VER_METADATA     "${METADATA}"

#define VER_STR          "${VER_STRING}"

#endif /* ${HEADER_GUARD} */
EOF
fi
